==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedRemoveProperty.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedRemovePropertyMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.processor.RemovePropertyProcessor;

@ManagedResource(description = "Managed RemoveProperty")
public class ManagedRemoveProperty extends ManagedProcessor implements ManagedRemovePropertyMBean {
    private final RemovePropertyProcessor processor;

    public ManagedRemoveProperty(CamelContext context, RemovePropertyProcessor processor, ProcessorDefinition<?> definition) {
        super(context, processor, definition);
        this.processor = processor;
    }

    @Override
    public String getPropertyName() {
        return processor.getPropertyName();
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/core/camel-management/src/main/java/org/apache/camel/management/mbean/ManagedRemoveProperty.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.management.mbean;

import org.apache.camel.CamelContext;
import org.apache.camel.api.management.ManagedResource;
import org.apache.camel.api.management.mbean.ManagedRemovePropertyMBean;
import org.apache.camel.model.ProcessorDefinition;
import org.apache.camel.processor.RemovePropertyProcessor;

@ManagedResource(description = "Managed RemoveProperty")
public class ManagedRemoveProperty extends ManagedProcessor implements ManagedRemovePropertyMBean {

    public ManagedRemoveProperty(CamelContext context, RemovePropertyProcessor processor, ProcessorDefinition<?> definition) {
        super(context, processor, definition);
    }

    @Override
    public RemovePropertyProcessor getProcessor() {
        return (RemovePropertyProcessor) super.getProcessor();
    }

    @Override
    public String getPropertyName() {
        return getProcessor().getPropertyName();
    }
}
